j\_chess\_lib.communication package
===================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   j_chess_lib.communication.schema

Module contents
---------------

.. automodule:: j_chess_lib.communication
   :members:
   :undoc-members:
   :show-inheritance:
